local debug = nil
--[===[@debug@
debug = true
--@end-debug@]===]

local L_CALL = "%s looted %s!"
local L_CALL_WITH_SOURCE = "%s looted %s (%s)!"

local ignoredItems = {
	[30316] = true, -- Devastation
	[30317] = true, -- Cosmic Infuser
	[30312] = true, -- Infinity Blade
	[30318] = true, -- Netherstrand Longbow
	[30313] = true, -- Staff of Disintegration
	[30311] = true, -- Warp Slicer
	[30320] = true, -- Bundle of Nether Spikes
	[30314] = true, -- Phaseshift Bulwark
	[30319] = true, -- Nether Spikes
	[29434] = true, -- Badge of Justice
	[22450] = true, -- Void Crystal
	[20725] = true, -- Nexus Crystal

	[32428] = true, -- Heart of Darkness

	[32230] = true, -- Shadowsong Amethyst
	[32249] = true, -- Seaspray Emerald
	[32231] = true, -- Pyrestone
	[32229] = true, -- Lionseye
	[32228] = true, -- Empyrean Sapphire
	[32227] = true, -- Crimson Spinel

	[36919] = true, -- Cardinal Ruby
	[36925] = true, -- Majestic Zircon
	[36922] = true, -- King's Amber
	[36928] = true, -- Dreadstone
	[36934] = true, -- Eye of Zul
	[36931] = true, -- Ametrine

	[34057] = true, -- Abyss Crystal
}

local pname = UnitName("player")
--local guildName = nil

local shouldTransmit = true
local f = CreateFrame("Frame")

local C_SELF = LOOT_ITEM_SELF:gsub("%%s", "(.+)")
local C_LOOT = LOOT_ITEM:gsub("%%s", "(.+)")
local C_SELF_M = LOOT_ITEM_SELF_MULTIPLE:gsub("%%s", "(.+)")
local C_LOOT_M = LOOT_ITEM_MULTIPLE:gsub("%%s", "(.+)")

local candidates = {}
local totalElapsed = 0
local function onUpdate(self, elapsed)
	totalElapsed = totalElapsed + elapsed
	if totalElapsed > 10 then
		self:SetScript("OnUpdate", nil)
		totalElapsed = 0
		if #candidates > 0 then
			table.sort(candidates)
			shouldTransmit = candidates[1] == pname and true or false
			wipe(candidates)
		else
			shouldTransmit = true
		end
	end
end
local function checkGroup()
	local i = select(2, IsInInstance())
	if i == "pvp" or i == "arena" then return end
	f:SetScript("OnUpdate", onUpdate)
	SendAddonMessage("BTC", "ping", "RAID")
	return true
end

local function getSource(looter)
	if UnitInRaid("player") then
		for i = 1, GetNumRaidMembers() do
			local u = "raid" .. i .. "target"
			if UnitExists(u) and UnitIsDead(u) and UnitClassification(u) == "worldboss" then
				return UnitName(u)
			end
		end
	else
		local unit = looter .. "-target"
		if UnitExists(unit) and UnitIsDead(unit) and UnitIsEnemy(looter, unit) then
			return UnitName(unit)
		end
	end
end

local function notify(msg)
	local item = msg:match(C_SELF)
	local player = pname
	if not item then player, item = msg:match(C_LOOT) end
	if not item then item = msg:match(C_SELF_M) end
	if not item then player, item = msg:match(C_LOOT_M) end
	if debug then
		if not item then print("BootyCall failed to parse: " .. msg)
		else print("BootyCall found: " .. tostring(item) .. "@" .. tostring(player)) end
	end
	if not item then return end

	local n, link, quality = GetItemInfo(item)
	if not quality or quality < 4 then return end
	local itemId = tonumber((select(3, link:find("item:(%d+):"))))
	if type(itemId) ~= "number" or ignoredItems[itemId] then return end
	local source = getSource(player)
	if source then
		SendChatMessage(L_CALL_WITH_SOURCE:format(player, link, source), "GUILD")
	else
		SendChatMessage(L_CALL:format(player, link), "GUILD")
	end
end

local lastSize = 0
f:SetScript("OnEvent", function(self, event, prefix, message, distribution, sender)
	if event == "CHAT_MSG_LOOT" then
		if not shouldTransmit then return end
		notify(prefix)
	elseif event == "CHAT_MSG_ADDON" then
		if prefix ~= "BTC" then return end
		if message == "ping" then
			SendAddonMessage("BTC", "pong", "RAID")
		end
		candidates[#candidates+1] = sender
	elseif event == "PLAYER_LOGIN" then
		if not IsInGuild() then return end

		--guildName = GetGuildInfo("player")

		self:RegisterEvent("CHAT_MSG_LOOT")
		self:RegisterEvent("CHAT_MSG_ADDON")
		self:RegisterEvent("PARTY_MEMBERS_CHANGED")
		self:RegisterEvent("RAID_ROSTER_UPDATE")
	else
		local size = UnitInRaid("player") and GetNumRaidMembers() or GetNumPartyMembers()
		if size == lastSize then return end
		if not checkGroup() then return end
		lastSize = size
	end
end)

f:RegisterEvent("PLAYER_LOGIN")
f:Show()

